rendered paste bodyhive@trace ~/ScrollZ $ ./configure --enable-ipv6
loading cache ./config.cache
this is ScrollZ version 1.9.5 + ircII version 20050423
checking for gcc... (cached) gcc
checking whether the C compiler (gcc ) works... yes
checking whether the C compiler (gcc ) is a cross-compiler... no
checking whether we are using GNU C... (cached) yes
checking whether gcc accepts -g... (cached) yes
checking how to run the C preprocessor... (cached) gcc -E
checking for POSIXized ISC... no
checking for NeXT... no
checking for AIX... no
checking for flex... (cached) flex
checking for yywrap in -lfl... (cached) yes
checking whether gcc needs -traditional... (cached) no
checking for getpwnam in -lsun... (cached) no
checking for qnx... no
checking for solaris... no
checking for SVR4... no
checking for -I/usr/netinclude... no
checking for hpux version... no
checking for ultrix... no
checking for sequent/ptx... no
checking for sys/un.h... (cached) yes
checking for sys/select.h... (cached) yes
checking for sys/fcntl.h... (cached) yes
checking for sys/ioctl.h... (cached) yes
checking for sys/file.h... (cached) yes
checking for sys/time.h... (cached) yes
checking for sys/wait.h... (cached) yes
checking for sys/twg_config.h... (cached) no
checking for sys/ptem.h... (cached) no
checking for sys/uio.h... (cached) yes
checking for unistd.h... (cached) yes
checking for fcntl.h... (cached) yes
checking for string.h... (cached) yes
checking for memory.h... (cached) yes
checking for netdb.h... (cached) yes
checking for limits.h... (cached) yes
checking for stdarg.h... (cached) yes
checking for process.h... (cached) no
checking for termcap.h... (cached) yes
checking for termios.h... (cached) yes
checking for fchmod... (cached) yes
checking for getcwd... (cached) yes
checking for getpgid... (cached) yes
checking for getsid... (cached) yes
checking for getloadavg... (cached) yes
checking for memmove... (cached) yes
checking for scandir... (cached) yes
checking for setsid... (cached) yes
checking for strerror... (cached) yes
checking for strftime... (cached) yes
checking for uname... (cached) yes
checking for writev... (cached) yes
checking for vasprintf... (cached) yes
checking for fputc... (cached) yes
checking for fwrite... (cached) yes
checking for snprintf... (cached) yes
checking for vsnprintf... (cached) yes
checking for ANSI C header files... (cached) yes
checking whether time.h and sys/time.h may both be included... (cached) yes
checking for dirent.h that defines DIR... (cached) yes
checking for opendir in -ldir... (cached) no
checking return type of signal handlers... (cached) void
checking for mode_t... (cached) yes
checking for pid_t... (cached) yes
checking for size_t... (cached) yes
checking for uid_t in sys/types.h... (cached) yes
checking for ssize_t... (cached) yes
checking for struct linger... yes
checking for waitpid... (cached) yes
checking for select... (cached) yes
checking for tgetent in -ltermcap... (cached) no
checking for tgetent in -ltinfo... (cached) no
checking for tgetent in -ltermlib... (cached) no
checking for tgetent in -lcurses... (cached) yes
checking for tputs in curses.h... no
checking signal implementation
checking for sigaction... (cached) yes
using posix signals
checking for waitpid declaration... yes
checking for errno declaration... yes
checking for sys_errlist declaration... yes
checking for a 32 bit integer... unsigned long
checking for socket in -lsocket... (cached) no
checking for socket in -linet... (cached) no
checking for gethostname... (cached) yes
checking for inet_addr in -ldgc... (cached) no
checking for gethostbyname in -lresolv... (cached) yes
checking for non-blocking... posix
generating a list of signal names...
checking for unix mail directory... /var/spool/mail
checking for ElectricFence library... no
checking paranoia status... none
checking for /dev/urandom... yes
checking for default server... none
checking for crypt in -lc... (cached) no
checking for crypt in -lcrypt... (cached) yes
checking whether to support SOCKS... no
checking whether to support SOCKS5... no
checking whether to support SOCKS4... no
checking whether to enable ipv6... yes
checking ipv6 stack type... linux-glibc
checking getaddrinfo bug... good
checking for struct sockaddr's sa_len... no
checking whether to enable SSL... no
checking whether to enable regexp support... no
checking whether to enable FiSH support... no
checking for pax... (cached) tar
checking for gzcat... (cached) gzcat
checking for sendmail... /usr/sbin/sendmail
creating ./config.status
creating Makefile
creating include/Makefile
creating source/Makefile
creating ircbug
creating include/defs.h
include/defs.h is unchanged
well there we are, you now might want to look in config.h and
see if there is anything you might want to tune, else you can
just run a make here.. good luck!
hive@trace ~/ScrollZ $ make
make[1]: Entering directory `/home/hive/ScrollZ/include'
gcc -o count count.c
rm -f vars.h
./count < vars.h.proto > vars.h
rm -f hook.h
./count < hook.h.proto > hook.h
rm -f keys.h
./count < keys.h.proto > keys.h
make[1]: Leaving directory `/home/hive/ScrollZ/include'
make[1]: Entering directory `/home/hive/ScrollZ/source'
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c alias.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c blowfish.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c cdcc.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c celerity.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c crypt.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c ctcp.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c dcc.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c debug.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c edit.c
edit.c:591: warning: initialization from incompatible pointer type
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c edit2.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DIRCPATH=\"~/.ScrollZ:/usr/local/share/scrollz/script:.\" -c edit3.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c edit4.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c edit5.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c edit6.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c exec.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c files.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c flood.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c funny.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DDEFAULT_HELP_PATH=\"/usr/local/share/scrollz/help\" -c help.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c history.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c hold.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c hook.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c if.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c ignore.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c input.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DIRCLIB=\"/usr/local/share/scrollz/\" -DIRCPATH=\"~/.ScrollZ:/usr/local/share/scrollz/script:.\" -c irc.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c ircaux.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c ircsig.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c keys.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c lastlog.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c list.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c log.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c mail.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c menu.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c names.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c newio.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c notice.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c notify.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c numbers.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c operv.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c output.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c parse.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c queue.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c reg.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c scandir.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DWSERV_PATH=\"/usr/local/bin/wserv\" -c screen.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DIRCIO_PATH=\"/usr/local/bin/ircio\" -c server.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c stack.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c status.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c term.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DTRANSLATION_PATH=\"/usr/local/share/scrollz/translation/\" -c translat.c
gcc -g -O2 -DHAVE_CONFIG_H -I../include -DDEFAULT_HELP_PATH=\"/usr/local/share/scrollz/help\" -c vars.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c whois.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c whowas.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c window.c
gcc -I../include -g -O2 -DHAVE_CONFIG_H -c rijndael-alg-ref.c
rijndael-alg-ref.c:39: error: array type has incomplete element type
rijndael-alg-ref.c:39: error: array type has incomplete element type
rijndael-alg-ref.c:40: error: array type has incomplete element type
rijndael-alg-ref.c:41: error: array type has incomplete element type
rijndael-alg-ref.c:42: error: array type has incomplete element type
rijndael-alg-ref.c:43: error: array type has incomplete element type
make[1]: *** [rijndael-alg-ref.o] Error 1
make[1]: Leaving directory `/home/hive/ScrollZ/source'
make: *** [scrollz] Error 2
hive@trace ~/ScrollZ $